@@ -29,10 +29,10 @@
 __all__ = ("YOUTUBE_API_BASE_URL", "YOUTUBE_API_SCOPES", "YouTubeBot", "ux")
 
 __productname__ = "chatto"
-__version__ = "0.4.1"
+__version__ = "0.4.2"
 __description__ = "A unified API wrapper for YouTube and Twitch chat bots."
 __url__ = "https://github.com/parafoxia/chatto"
-__docs__ = "https://chatto.readthedocs.io/en/latest"
+__docs__ = "https://parafoxia.github.io/chatto/chatto/"
 __author__ = "Ethan Henderson"
 __author_email__ = "ethan.henderson.1998@gmail.com"
 __license__ = "BSD 3-Clause 'New' or 'Revised' License"
